@@ -16,6 +16,13 @@ if (isset($_POST['sql_query'])) {
         $_REQUEST['db'],
         $pmaThemeImage
     );
+} if (isset($_GET['tables'])) {
+    $constrains = $GLOBALS['dbi']->getForeignKeyConstrains(
+        $_REQUEST['db'],
+        $_GET['tables']
+    );
+    $response = Response::getInstance();
+    $response->addJSON('foreignKeyConstrains',$constrains);
 } else {
     $response = Response::getInstance();
 
@@ -23,6 +30,7 @@ if (isset($_POST['sql_query'])) {
     $scripts = $header->getScripts();
     $scripts->addFile('vendor/jquery/jquery.md5.js');
     $scripts->addFile('db_multi_table_query.js');
+    $scripts->addFile('db_query_generator.js');
 
     $queryInstance = new MultiTableQuery($GLOBALS['dbi'], $db);
 
