@@ -371,6 +371,12 @@ class TableStructureController extends TableController
             $this->db, $this->table, null, true
         );
 
+        foreach ($fields as $key => $row) {
+            if ('text' === substr($row['Type'], -4)) {
+                $fields[$key]['Default'] = stripcslashes(substr($row['Default'], 1, -1));
+            }
+        }
+
         //display table structure
         $this->response->addHTML(
             $this->displayStructure(
@@ -437,7 +443,7 @@ class TableStructureController extends TableController
             $data['Expression'] = '';
             if (isset($data['Extra']) && in_array($data['Extra'], $virtual)) {
                 $data['Virtuality'] = str_replace(' GENERATED', '', $data['Extra']);
-                $expressions = $this->table->getColumnGenerationExpression($column);
+                $expressions = $this->table_obj->getColumnGenerationExpression($column);
                 $data['Expression'] = $expressions[$column];
             }
 
@@ -518,7 +524,7 @@ class TableStructureController extends TableController
         $fields_meta = array();
         for ($i = 0; $i < $selected_cnt; $i++) {
             $value = $this->dbi->getColumns(
-                $this->db, $this->table, $selected[$i], true
+                $this->db, $this->table, $this->dbi->escapeString($selected[$i]), true
             );
             if (count($value) == 0) {
                 $message = Message::error(
@@ -883,7 +889,7 @@ class TableStructureController extends TableController
                 $_POST['field_length'][$i],
                 $_POST['field_attribute'][$i],
                 Util::getValueByKey($_POST, "field_collation.${i}", ''),
-                Util::getValueByKey($_POST, "field_null.${i}", 'NOT NULL'),
+                Util::getValueByKey($_POST, "field_null.${i}", 'NO'),
                 $_POST['field_default_type'][$i],
                 $_POST['field_default_value'][$i],
                 Util::getValueByKey($_POST, "field_extra.${i}", false),
@@ -969,7 +975,18 @@ class TableStructureController extends TableController
                         $_POST['field_orig'][$i]
                     )
                     . ' ' . Util::backquote($_POST['field_orig'][$i])
-                    . ' BLOB;';
+                    . ' BLOB';
+
+                    if (isset($_POST['field_virtuality'][$i])
+                        && isset($_POST['field_expression'][$i])) {
+                        if ($_POST['field_virtuality'][$i]) {
+                            $secondary_query .= ' AS (' . $_POST['field_expression'][$i] . ') '
+                                . $_POST['field_virtuality'][$i];
+                        }
+                    }
+
+                    $secondary_query .= ';';
+
                     $this->dbi->query($secondary_query);
                     $changedToBlob[$i] = true;
                 } else {
@@ -1019,7 +1036,7 @@ class TableStructureController extends TableController
                             $_POST['field_length_orig'][$i],
                             $_POST['field_attribute_orig'][$i],
                             Util::getValueByKey($_POST, "field_collation_orig.${i}", ''),
-                            Util::getValueByKey($_POST, "field_null_orig.${i}", 'NOT NULL'),
+                            Util::getValueByKey($_POST, "field_null_orig.${i}", 'NO'),
                             $_POST['field_default_type_orig'][$i],
                             $_POST['field_default_value_orig'][$i],
                             Util::getValueByKey($_POST, "field_extra_orig.${i}", false),
@@ -1220,52 +1237,11 @@ class TableStructureController extends TableController
             'DistinctValues' => Util::getIcon('b_browse', __('Distinct values')),
         );
 
-        /**
-         * Work on the table
-         */
+        $edit_view_url = '';
         if ($this->_tbl_is_view && ! $this->_db_is_system_schema) {
-            $item = $this->dbi->fetchSingleRow(
-                sprintf(
-                    "SELECT `VIEW_DEFINITION`, `CHECK_OPTION`, `DEFINER`,
-                      `SECURITY_TYPE`
-                    FROM `INFORMATION_SCHEMA`.`VIEWS`
-                    WHERE TABLE_SCHEMA='%s'
-                    AND TABLE_NAME='%s';",
-                    $GLOBALS['dbi']->escapeString($this->db),
-                    $GLOBALS['dbi']->escapeString($this->table)
-                )
+            $edit_view_url = Url::getCommon(
+                array('db' => $this->db, 'table' => $this->table)
             );
-
-            $createView = $this->dbi->getTable($this->db, $this->table)
-                ->showCreate();
-            // get algorithm from $createView of the form
-            // CREATE ALGORITHM=<ALGORITHM> DE...
-            $parts = explode(" ", substr($createView, 17));
-            $item['ALGORITHM'] = $parts[0];
-
-            $view = array(
-                'operation' => 'alter',
-                'definer' => $item['DEFINER'],
-                'sql_security' => $item['SECURITY_TYPE'],
-                'name' => $this->table,
-                'as' => $item['VIEW_DEFINITION'],
-                'with' => $item['CHECK_OPTION'],
-                'algorithm' => $item['ALGORITHM'],
-            );
-
-            $edit_view_url = 'view_create.php'
-                . Url::getCommon($url_params) . '&amp;'
-                . implode(
-                    '&amp;',
-                    array_map(
-                        function ($key, $val) {
-                            return 'view[' . urlencode($key) . ']=' . urlencode(
-                                $val
-                            );
-                        },
-                        array_keys($view), $view
-                    )
-                );
         }
 
         /**
@@ -1299,7 +1275,7 @@ class TableStructureController extends TableController
                 'tbl_storage_engine' => $this->_tbl_storage_engine,
                 'primary' => $primary_index,
                 'columns_with_unique_index' => $columns_with_unique_index,
-                'edit_view_url' => isset($edit_view_url) ? $edit_view_url : null,
+                'edit_view_url' => $edit_view_url,
                 'columns_list' => $columns_list,
                 'table_stats' => isset($tablestats) ? $tablestats : null,
                 'fields' => $fields,
@@ -1313,6 +1289,7 @@ class TableStructureController extends TableController
                 'relation_mimework' => $GLOBALS['cfgRelation']['mimework'],
                 'central_columns_work' => $GLOBALS['cfgRelation']['centralcolumnswork'],
                 'mysql_int_version' => $GLOBALS['dbi']->getVersion(),
+                'is_mariadb' => $GLOBALS['dbi']->isMariaDB(),
                 'pma_theme_image' => $GLOBALS['pmaThemeImage'],
                 'text_dir' => $GLOBALS['text_dir'],
                 'is_active' => Tracker::isActive(),
