@@ -444,6 +444,13 @@ class LanguageManager
             'nb|norwegian',
             'nb_NO',
         ),
+        'nn' => array(
+            'nn',
+            'Norwegian Nynorsk',
+            'Nynorsk',
+            'nn|nynorsk',
+            'nn_NO',
+        ),
         'nl' => array(
             'nl',
             'Dutch',
@@ -516,7 +523,7 @@ class LanguageManager
         ),
         'sq' => array(
             'sq',
-            'Slbanian',
+            'Albanian',
             'Shqip',
             'sq|albanian',
             'sq_AL',
@@ -719,11 +726,11 @@ class LanguageManager
     {
         if (! $this->_available_locales) {
 
-            if (empty($GLOBALS['cfg']['FilterLanguages'])) {
+            if (! isset($GLOBALS['PMA_Config']) || empty($GLOBALS['PMA_Config']->get('FilterLanguages'))) {
                 $this->_available_locales = $this->listLocaleDir();
             } else {
                 $this->_available_locales = preg_grep(
-                    '@' . $GLOBALS['cfg']['FilterLanguages'] . '@',
+                    '@' . $GLOBALS['PMA_Config']->get('FilterLanguages') . '@',
                     $this->listLocaleDir()
                 );
             }
