@@ -5,7 +5,7 @@
  *
  * @package PhpMyAdmin
  */
-use PMA\libraries\URL;
+use PhpMyAdmin\Url;
 
 if (! defined('PHPMYADMIN')) {
     exit;
@@ -24,7 +24,7 @@ if (empty($viewing_mode)) {
 /**
  * Set parameters for links
  */
-$GLOBALS['url_query'] = URL::getCommon(array('db' => $db));
+$GLOBALS['url_query'] = Url::getCommon();
 
 /**
  * Defines the urls to return to in case of error in a sql statement
@@ -34,21 +34,10 @@ $err_url = 'index.php' . $GLOBALS['url_query'];
 /**
  * @global boolean Checks for superuser privileges
  */
-$GLOBALS['is_superuser'] = $GLOBALS['dbi']->isSuperuser();
 $GLOBALS['is_grantuser'] = $GLOBALS['dbi']->isUserType('grant');
 $GLOBALS['is_createuser'] = $GLOBALS['dbi']->isUserType('create');
 
 // now, select the mysql db
-if ($GLOBALS['is_superuser']) {
-    $GLOBALS['dbi']->selectDb('mysql', $GLOBALS['userlink']);
+if ($GLOBALS['dbi']->isSuperuser()) {
+    $GLOBALS['dbi']->selectDb('mysql');
 }
-
-PMA\libraries\Util::checkParameters(
-    array('is_superuser', 'url_query'), false
-);
-
-/**
- * shared functions for server page
- */
-require_once './libraries/server_common.lib.php';
-
