@@ -224,6 +224,10 @@ input[type=number] {
     width: 50px;
 }
 
+input#auto_increment_opt {
+    width: min-content;
+}
+
 input[type=text],
 input[type=password],
 input[type=number],
@@ -713,6 +717,7 @@ td .icon {
 
 /* message boxes: error, confirmation */
 #pma_errors, #pma_demo, #pma_footer {
+    position: relative;
     padding: 0 0.5em;
 }
 
@@ -901,9 +906,10 @@ body#loginform div.container {
 }
 
 form.login label {
-    float: <?php echo $left; ?>;
     width: 10em;
     font-weight: bolder;
+    display: inline-block;
+    margin-<?php echo $left; ?>: 2em;
 }
 
 form.login input[type=text],
@@ -955,6 +961,9 @@ form.login select {
     display: inline-block;
 }
 
+li.last.database{
+    margin-bottom: 15px
+}
 /******************************************************************************/
 /* specific elements */
 
@@ -2709,6 +2718,7 @@ fieldset .disabled-field td {
 }
 
 .pma_table th.draggable span,
+.sticky_columns th.draggable span,
 .pma_table tbody td span {
     display: block;
     overflow: hidden;
